@@ -104,7 +104,7 @@ def ProcessFiles(sourceFile):
 
     PrLightPurple('Copying ' + sourceFile)
     for i in range (len(targetLangs)):
-        shutil.copy(sourceFile, targetPaths[i] + '/' + '/'.join(sourceFile.split('/')[2:]))
+        shutil.copy(sourceFile, targetPaths[i] + '/' + '/'.join(sourceFile.split('/')[1:]))
 
 #--------------------------------
 
@@ -196,7 +196,7 @@ def root():
         re.purge
         exit()
     allModified = modifiedStaged + modifiedUnstaged
-    workTree = [n.a_blob.path for n in allModified if n.a_blob.path.split('/')[0] == '_'.join(sourceLang.split('-')).lower()] + repo.untracked_files
+    workTree = [n.a_blob.path for n in allModified if n.a_blob.path.split('/')[0] == '_'.join(sourceLang.split('-')).lower()] + [repo.untracked_files for n[1:] in os.listdir(sourceDir)] 
 
     # option = input(' Digite uma opção:\n [1] para traduzir arquivos modificados desde o último commit,\n [2] para traduzir todo o projeto, ou\n [Enter] para sair: ')
 
@@ -231,7 +231,7 @@ def diff():
                 else:
                     for path in targetPaths:
                         try:
-                            os.remove(path + '/' + '/'.join(doc.split('/')[2:]))
+                            os.remove(path + '/' + '/'.join(doc.split('/')[1:]))
                         except:
                             pass
             PrGreen('\n\n Completed successfully!')
